==> rheolef_5.93.orig.tar.gz: rheolef-5.93/skit/ptst2/array_of_idxset_tst.cc <==
///
/// This file is part of Rheolef.
///
/// Copyright (C) 2000-2009 Pierre Saramito <Pierre.Saramito@imag.fr>
///
/// Rheolef is free software; you can redistribute it and/or modify
/// it under the terms of the GNU General Public License as published by
/// the Free Software Foundation; either version 2 of the License, or
/// (at your option) any later version.
///
/// Rheolef is distributed in the hope that it will be useful,
/// but WITHOUT ANY WARRANTY; without even the implied warranty of
/// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
/// GNU General Public License for more details.
///
/// You should have received a copy of the GNU General Public License
/// along with Rheolef; if not, write to the Free Software
/// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
///
/// =========================================================================
# include "rheolef/distributed.h"
# include "rheolef/array.h"
# include "rheolef/index_set.h"
using namespace rheolef;
using namespace std;

// ======================================================
int main(int argc, char**argv) {
// ======================================================
    environment distributed(argc, argv);
    communicator comm;
    if (comm.size() != 3) {
	warning_macro ("expect np=3 processors, find np="<<comm.size());
	return 0;
    }
    size_t n = 3;
    array<index_set> x(n);
    switch (comm.rank()) {
      case 0: {
	x[0] += 100;
	index_set val;
	val += 201;
	val += 301;
	x.dis_entry(1) += val;
	break;
      }
      case 1: {
	x[0] += 101;
	index_set val;
	val += 200;
	x.dis_entry(1) += val;
	break;
      }
      case 2: {
	x[0] += 102;
	index_set val;
	val += 401;
#define BUG
#ifdef BUG
	x.dis_entry(1) += val;
#else // BUG
	x.dis_entry(2) += val;
#endif // BUG
	break;
      }
    }
    x.dis_entry_assembly (index_set_add_op<index_set,index_set>());
    dcout << x.dis_size() << endl
          << x            << endl;
#ifdef TODO
#endif // TODO
}

==> rheolef_6.1.orig.tar.gz: rheolef-6.1/skit/ptst2/array_of_idxset_tst.cc <==
///
/// This file is part of Rheolef.
///
/// Copyright (C) 2000-2009 Pierre Saramito <Pierre.Saramito@imag.fr>
///
/// Rheolef is free software; you can redistribute it and/or modify
/// it under the terms of the GNU General Public License as published by
/// the Free Software Foundation; either version 2 of the License, or
/// (at your option) any later version.
///
/// Rheolef is distributed in the hope that it will be useful,
/// but WITHOUT ANY WARRANTY; without even the implied warranty of
/// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
/// GNU General Public License for more details.
///
/// You should have received a copy of the GNU General Public License
/// along with Rheolef; if not, write to the Free Software
/// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
///
/// =========================================================================
# include "rheolef/distributed.h"
# include "rheolef/array.h"
# include "rheolef/index_set.h"
using namespace rheolef;
// ======================================================
int main(int argc, char**argv) {
// ======================================================
    environment rheolef(argc, argv);
    communicator comm;
    if (comm.size() != 3) {
	warning_macro ("expect np=3 processors, find np="<<comm.size());
	return 0;
    }
    size_t n = 3;
    array<index_set> x(n);
    switch (comm.rank()) {
      case 0: {
	x[0] += 100;
	index_set val;
	val += 201;
	val += 301;
	x.dis_entry(1) += val;
	break;
      }
      case 1: {
	x[0] += 101;
	index_set val;
	val += 200;
	x.dis_entry(1) += val;
	break;
      }
      case 2: {
	x[0] += 102;
	index_set val;
	val += 401;
#define BUG
#ifdef BUG
	x.dis_entry(1) += val;
#else // BUG
	x.dis_entry(2) += val;
#endif // BUG
	break;
      }
    }
    x.dis_entry_assembly (index_set_add_op<index_set,index_set>());
    dout << x.dis_size() << std::endl
         << x            << std::endl;
#ifdef TODO
#endif // TODO
}
